# ncurses 6.0 - patch 20171223 - Thomas E. Dickey
#
# ------------------------------------------------------------------------------
#
# Ncurses 6.0 is at
# 	ftp.gnu.org:/pub/gnu
#
# Patches for ncurses 6.0 can be found at
# 	ftp://ftp.invisible-island.net/ncurses/6.0
#	http://invisible-mirror.net/archives/ncurses/6.0 
#
# ------------------------------------------------------------------------------
# ftp://ftp.invisible-island.net/ncurses/6.0/ncurses-6.0-20171223.patch.gz
# patch by Thomas E. Dickey <dickey@invisible-island.net>
# created  Sat Dec 23 23:06:29 UTC 2017
# ------------------------------------------------------------------------------
# NEWS                             |   14 +++++++++++++-
# VERSION                          |    2 +-
# dist.mk                          |    4 ++--
# ncurses/tinfo/lib_termcap.c      |   12 ++++++++----
# package/debian-mingw/changelog   |    4 ++--
# package/debian-mingw64/changelog |    4 ++--
# package/debian/changelog         |    4 ++--
# package/mingw-ncurses.nsi        |    4 ++--
# package/mingw-ncurses.spec       |    2 +-
# package/ncurses.spec             |    2 +-
# progs/toe.c                      |    9 +++------
# test/movewindow.c                |    4 ++--
# test/test.priv.h                 |    8 ++++++--
# test/testcurs.c                  |    4 ++--
# test/tracemunch                  |    4 ++--
# 15 files changed, 49 insertions(+), 32 deletions(-)
# ------------------------------------------------------------------------------
Index: NEWS
Prereq:  1.3025 
--- ncurses-6.0-20171216+/NEWS	2017-12-17 00:14:16.000000000 +0000
+++ ncurses-6.0-20171223/NEWS	2017-12-23 21:44:36.000000000 +0000
@@ -25,7 +25,7 @@
 -- sale, use or other dealings in this Software without prior written        --
 -- authorization.                                                            --
 -------------------------------------------------------------------------------
--- $Id: NEWS,v 1.3025 2017/12/17 00:14:16 tom Exp $
+-- $Id: NEWS,v 1.3030 2017/12/23 21:44:36 tom Exp $
 -------------------------------------------------------------------------------
 
 This is a log of changes that ncurses has gone through since Zeyd started
@@ -45,6 +45,18 @@
 Changes through 1.9.9e did not credit all contributions;
 it is not possible to add this information.
 
+20171223
+	+ modify ncurses-examples to quiet const-warnings when building with
+	  PDCurses.
+	+ modify toe to not exit if unable to read a terminal description,
+	  e.g., if there is a permission problem.
+	+ minor fix for progs/toe.c, using _nc_free_termtype2.
+	+ assign 0 to pointer in _nc_tgetent_leak() after freeing it. Also
+	  avoid reusing pointer from previous successful call to tgetent
+	  if the latest call is unsuccessful (patch by Michael Schroeder,
+	  OpenSuSE #1070450).
+	+ minor fix for test/tracemunch, initialize $awaiting variable.
+
 20171216
 	+ repair template in test/package/ncurses-examples.spec (cf: 20171111).
 	+ improve tic's warning about the number of parameters tparm might use
Index: VERSION
--- ncurses-6.0-20171216+/VERSION	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/VERSION	2017-12-17 20:03:11.000000000 +0000
@@ -1 +1 @@
-5:0:9	6.0	20171216
+5:0:9	6.0	20171223
Index: dist.mk
Prereq:  1.1196 
--- ncurses-6.0-20171216+/dist.mk	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/dist.mk	2017-12-17 20:03:11.000000000 +0000
@@ -25,7 +25,7 @@
 # use or other dealings in this Software without prior written               #
 # authorization.                                                             #
 ##############################################################################
-# $Id: dist.mk,v 1.1196 2017/12/11 01:17:12 tom Exp $
+# $Id: dist.mk,v 1.1197 2017/12/17 20:03:11 tom Exp $
 # Makefile for creating ncurses distributions.
 #
 # This only needs to be used directly as a makefile by developers, but
@@ -37,7 +37,7 @@
 # These define the major/minor/patch versions of ncurses.
 NCURSES_MAJOR = 6
 NCURSES_MINOR = 0
-NCURSES_PATCH = 20171216
+NCURSES_PATCH = 20171223
 
 # We don't append the patch to the version, since this only applies to releases
 VERSION = $(NCURSES_MAJOR).$(NCURSES_MINOR)
Index: ncurses/tinfo/lib_termcap.c
Prereq:  1.84 
--- ncurses-6.0-20171216+/ncurses/tinfo/lib_termcap.c	2017-04-11 01:15:11.000000000 +0000
+++ ncurses-6.0-20171223/ncurses/tinfo/lib_termcap.c	2017-12-23 18:18:13.000000000 +0000
@@ -48,7 +48,7 @@
 #define CUR SP_TERMTYPE
 #endif
 
-MODULE_ID("$Id: lib_termcap.c,v 1.84 2017/04/11 01:15:11 tom Exp $")
+MODULE_ID("$Id: lib_termcap.c,v 1.86 2017/12/23 18:18:13 tom Exp $")
 
 NCURSES_EXPORT_VAR(char *) UP = 0;
 NCURSES_EXPORT_VAR(char *) BC = 0;
@@ -153,8 +153,12 @@
 	}
 	CacheInx = best;
     }
-    LAST_TRM = TerminalOf(SP_PARM);
-    LAST_SEQ = ++CacheSeq;
+    if (rc == 1) {
+	LAST_TRM = TerminalOf(SP_PARM);
+	LAST_SEQ = ++CacheSeq;
+    } else {
+	LAST_TRM = 0;
+    }
 
     PC = 0;
     UP = 0;
@@ -401,7 +405,7 @@
 	int num;
 	for (CacheInx = 0; CacheInx < TGETENT_MAX; ++CacheInx) {
 	    if (LAST_TRM == termp) {
-		FreeIfNeeded(FIX_SGR0);
+		FreeAndNull(FIX_SGR0);
 		if (LAST_TRM != 0) {
 		    LAST_TRM = 0;
 		}
Index: package/debian-mingw/changelog
--- ncurses-6.0-20171216+/package/debian-mingw/changelog	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/package/debian-mingw/changelog	2017-12-17 20:03:11.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (6.0+20171216) unstable; urgency=low
+ncurses6 (6.0+20171223) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 10 Dec 2017 20:17:12 -0500
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 17 Dec 2017 15:03:11 -0500
 
 ncurses6 (5.9-20131005) unstable; urgency=low
 
Index: package/debian-mingw64/changelog
--- ncurses-6.0-20171216+/package/debian-mingw64/changelog	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/package/debian-mingw64/changelog	2017-12-17 20:03:11.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (6.0+20171216) unstable; urgency=low
+ncurses6 (6.0+20171223) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 10 Dec 2017 20:17:12 -0500
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 17 Dec 2017 15:03:11 -0500
 
 ncurses6 (5.9-20131005) unstable; urgency=low
 
Index: package/debian/changelog
--- ncurses-6.0-20171216+/package/debian/changelog	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/package/debian/changelog	2017-12-17 20:03:11.000000000 +0000
@@ -1,8 +1,8 @@
-ncurses6 (6.0+20171216) unstable; urgency=low
+ncurses6 (6.0+20171223) unstable; urgency=low
 
   * latest weekly patch
 
- -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 10 Dec 2017 20:17:12 -0500
+ -- Thomas E. Dickey <dickey@invisible-island.net>  Sun, 17 Dec 2017 15:03:11 -0500
 
 ncurses6 (5.9-20120608) unstable; urgency=low
 
Index: package/mingw-ncurses.nsi
Prereq:  1.244 
--- ncurses-6.0-20171216+/package/mingw-ncurses.nsi	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/package/mingw-ncurses.nsi	2017-12-17 20:03:11.000000000 +0000
@@ -1,4 +1,4 @@
-; $Id: mingw-ncurses.nsi,v 1.244 2017/12/11 01:17:12 tom Exp $
+; $Id: mingw-ncurses.nsi,v 1.245 2017/12/17 20:03:11 tom Exp $
 
 ; TODO add examples
 ; TODO bump ABI to 6
@@ -10,7 +10,7 @@
 !define VERSION_MAJOR "6"
 !define VERSION_MINOR "0"
 !define VERSION_YYYY  "2017"
-!define VERSION_MMDD  "1216"
+!define VERSION_MMDD  "1223"
 !define VERSION_PATCH ${VERSION_YYYY}${VERSION_MMDD}
 
 !define MY_ABI   "5"
Index: package/mingw-ncurses.spec
--- ncurses-6.0-20171216+/package/mingw-ncurses.spec	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/package/mingw-ncurses.spec	2017-12-17 20:03:11.000000000 +0000
@@ -3,7 +3,7 @@
 Summary: shared libraries for terminal handling
 Name: mingw32-ncurses6
 Version: 6.0
-Release: 20171216
+Release: 20171223
 License: X11
 Group: Development/Libraries
 Source: ncurses-%{version}-%{release}.tgz
Index: package/ncurses.spec
--- ncurses-6.0-20171216+/package/ncurses.spec	2017-12-11 01:17:12.000000000 +0000
+++ ncurses-6.0-20171223/package/ncurses.spec	2017-12-17 20:03:11.000000000 +0000
@@ -1,7 +1,7 @@
 Summary: shared libraries for terminal handling
 Name: ncurses6
 Version: 6.0
-Release: 20171216
+Release: 20171223
 License: X11
 Group: Development/Libraries
 Source: ncurses-%{version}-%{release}.tgz
Index: progs/toe.c
Prereq:  1.75 
--- ncurses-6.0-20171216+/progs/toe.c	2017-04-05 23:19:24.000000000 +0000
+++ ncurses-6.0-20171223/progs/toe.c	2017-12-23 19:23:40.000000000 +0000
@@ -44,7 +44,7 @@
 #include <hashed_db.h>
 #endif
 
-MODULE_ID("$Id: toe.c,v 1.75 2017/04/05 23:19:24 tom Exp $")
+MODULE_ID("$Id: toe.c,v 1.77 2017/12/23 19:23:40 tom Exp $")
 
 #define isDotname(name) (!strcmp(name, ".") || !strcmp(name, ".."))
 
@@ -440,11 +440,8 @@
 			(void) fprintf(stderr,
 				       "%s: couldn't open terminfo file %s.\n",
 				       _nc_progname, name_2);
-			free(cwd_buf);
 			free(name_2);
-			closedir(entrydir);
-			closedir(termdir);
-			return (EXIT_FAILURE);
+			continue;
 		    }
 
 		    /* only visit things once, by primary name */
@@ -489,7 +486,7 @@
 				cn = _nc_first_name(lterm.term_names);
 				/* apply the selected hook function */
 				hook(i, eargc, cn, &lterm);
-				_nc_free_termtype(&lterm);
+				_nc_free_termtype2(&lterm);
 			    }
 			}
 			code = _nc_db_next(capdbp, &key, &data);
Index: test/movewindow.c
Prereq:  1.45 
--- ncurses-6.0-20171216+/test/movewindow.c	2017-09-06 20:08:11.000000000 +0000
+++ ncurses-6.0-20171223/test/movewindow.c	2017-12-23 21:36:59.000000000 +0000
@@ -26,7 +26,7 @@
  * authorization.                                                           *
  ****************************************************************************/
 /*
- * $Id: movewindow.c,v 1.45 2017/09/06 20:08:11 tom Exp $
+ * $Id: movewindow.c,v 1.46 2017/12/23 21:36:59 tom Exp $
  *
  * Demonstrate move functions for windows and derived windows from the curses
  * library.
@@ -54,7 +54,7 @@
 #undef derwin
 #endif
 
-#ifdef NCURSES_VERSION
+#if defined(NCURSES_VERSION) || defined(PDCURSES)
 #define CONST_FMT const
 #else
 #define CONST_FMT		/* nothing */
Index: test/test.priv.h
Prereq:  1.160 
--- ncurses-6.0-20171216+/test/test.priv.h	2017-10-12 01:00:59.000000000 +0000
+++ ncurses-6.0-20171223/test/test.priv.h	2017-12-23 21:40:21.000000000 +0000
@@ -29,7 +29,7 @@
 /****************************************************************************
  *  Author: Thomas E. Dickey                    1996-on                     *
  ****************************************************************************/
-/* $Id: test.priv.h,v 1.160 2017/10/12 01:00:59 tom Exp $ */
+/* $Id: test.priv.h,v 1.161 2017/12/23 21:40:21 tom Exp $ */
 
 #ifndef __TEST_PRIV_H
 #define __TEST_PRIV_H 1
@@ -887,8 +887,12 @@
  * that XSI shows.
  */
 #ifndef NCURSES_CONST
+#ifdef PDCURSES
+#define NCURSES_CONST		const /* close enough */
+#else
 #define NCURSES_CONST		/* nothing */
 #endif
+#endif
 
 /* out-of-band values for representing absent capabilities */
 #define ABSENT_BOOLEAN		((signed char)-1)	/* 255 */
@@ -974,7 +978,7 @@
 /*
  * ncurses uses const in some places where X/Open does (or did) not allow.
  */
-#ifdef NCURSES_VERSION
+#if defined(NCURSES_VERSION) || defined(PDCURSES)
 #define CONST_MENUS const
 #else
 #define CONST_MENUS		/* nothing */
Index: test/testcurs.c
Prereq:  1.52 
--- ncurses-6.0-20171216+/test/testcurs.c	2017-09-04 11:49:55.000000000 +0000
+++ ncurses-6.0-20171223/test/testcurs.c	2017-12-23 21:38:26.000000000 +0000
@@ -6,13 +6,13 @@
  *  wrs(5/28/93) -- modified to be consistent (perform identically) with either
  *                  PDCurses or under Unix System V, R4
  *
- * $Id: testcurs.c,v 1.52 2017/09/04 11:49:55 tom Exp $
+ * $Id: testcurs.c,v 1.53 2017/12/23 21:38:26 tom Exp $
  */
 
 #include <test.priv.h>
 
 #if defined(XCURSES)
-char *XCursesProgramName = "testcurs";
+const char *XCursesProgramName = "testcurs";
 #endif
 
 static int initTest(WINDOW **);
Index: test/tracemunch
Prereq:  1.16 
--- ncurses-6.0-20171216+/test/tracemunch	2017-08-09 23:59:00.000000000 +0000
+++ ncurses-6.0-20171223/test/tracemunch	2017-12-23 17:51:31.000000000 +0000
@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: tracemunch,v 1.16 2017/08/09 23:59:00 tom Exp $
+# $Id: tracemunch,v 1.17 2017/12/23 17:51:31 tom Exp $
 ##############################################################################
 # Copyright (c) 1998-2005,2017 Free Software Foundation, Inc.                #
 #                                                                            #
@@ -92,7 +92,7 @@
 while (<STDIN>) {
     my $addr;
     my $n;
-    my $awaiting;
+    my $awaiting = "";
 
   CLASSIFY: {
 
